@@ -31,15 +31,24 @@ class IntrinsicCalibSession(CalibrationSession, ABC):
             if not os.path.exists('CapturedNumpyData'):
                 os.mkdir('CapturedNumpyData')
             os.mkdir('CapturedNumpyData/Intrinsic/')
-            
-        for i in range(self.no):
-            # Display camera stream
-            self.camera.viewCameraStream()
-            # Save images for calibration in .RAW and .PNG format
-            filename = 'intr_' + str(i)
-            self.camera.getImage(name= 'Intrinsic/'+ filename, calibration=True)
-            print("Alternate the viewing direction of the camera..." + str(i))
-        cv2.destroyAllWindows()
+        
+        try:
+            for i in range(self.no):
+                # Display camera stream
+                self.camera.viewCameraStream(i)
+                # Save images for calibration in .RAW and .PNG format
+                filename = 'intr_' + str(i)
+                self.camera.getImage(name= 'Intrinsic/' + filename, calibration=True)
+                print("Alternate the viewing direction of the camera..." + str(i+1))
+            self.camera.quit_and_open()
+            cv2.destroyAllWindows()
+            cv2.waitKey(1)
+            cv2.waitKey(1)
+        except KeyboardInterrupt:
+            self.camera.quit_and_open()
+            cv2.destroyAllWindows()
+            cv2.waitKey(1)
+            cv2.waitKey(1)
 
     def calibrate(self, imgFolder='CalibrationImages/Intrinsic', imgPattern="*.PNG"):
         # Call calibration in calibration object
