@@ -534,19 +534,13 @@ class Flir(Camera, ABC):
         cv2.destroyWindow("Live View")
 
     def viewCameraStream(self):
-
-        img = self.getImage(saveImage=False, saveNumpy=False)
-
+        
         while True:
-
-            _,img = self.Cam.grabFrameCont()
-            cv2.imshow('FLIR camera image', img)
+            _,img = self.Cam.grabFrame()
+            cv2.imshow('FLIR camera image ' + str(no), img)
             c = cv2.waitKey(1)
             if c != -1:
                 # When everything done, release the capture
-                self.Cam._camera.EndAcquisition()
-                cv2.destroyAllWindows()
-                self.quit_and_open()
                 break
 
             
@@ -554,7 +548,6 @@ class Flir(Camera, ABC):
     def viewCameraStreamJupyter(self):
 
         # Live view in a Jupyter Notebook
-
         try:
             start = self.getImage(saveImage=False, saveNumpy=False)
             start = start.astype(np.uint8)
@@ -646,7 +639,7 @@ class Flir(Camera, ABC):
 
         self.Cam.release()
 
-        self.Cam = psc(1, self._isMonochrome, self._is16bits)
+        self.Cam = psc(0, self._isMonochrome, self._is16bits)
 
 
 
